# Glossary of Terms

## aberration
The apparent angular displacement of a celestial object from its geometric position, caused by the motion of the observer with respect to the object, and the finite speed of light.

## age of Moon
The angle between the Sun and the Moon measured at the Earth.

## altitude
The angle up from the horizon.

## annual equation
A correction of the Moon’s orbital motion due to the variation of the Sun–Earth distance as the Earth travels in its own ellipse about the Sun.

## anomaly
The angle at the focus or the centre of an orbital ellipse between the major axis and the orbiting body or its projection.

## apastron
The point in an orbit about a star that is furthest from the star.

## aphelion
The point in an orbit about the Sun most distant from the Sun.

## apogee
The point in an orbit about the Earth most distant from the Earth.

## Astronomical Almanac
A collection of tables predicting the positions and circumstances of astronomical phenomena. This title replaced both the _American Ephemeris and Nautical Almanac_ and the _Astronomical Ephemeris_, beginning with the 1981 edition.

## Astronomical Ephemeris
_see Astronomical Almanac._

## astronomical latitude
The angle between the astronomical zenith and the equator.

## astronomical unit
Approximately equal to the length of the semi-major axis of the Earth’s orbit about the Sun, 1.496 × 10 11 metres.

## atmospheric refraction
The apparent shift in the position of a celestial object due to the bending of light rays by the atmosphere.

## azimuth
The angle round from the north point measured on the horizon in the sense NESW.

## binary star
A pair of stars bound together by their mutual gravitational attraction, both in orbit about their common centre of mass.

## calendar
System of accounting the days in the year. The **Julian calendar**, introduced by Julius Caesar, divides the year into 365 days except for every fourth year which has 366. The **Gregorian calendar**, introduced by Pope Gregory XIII (1502–1585) in 1582 and accepted in England in 1752, is the one generally in use in the West today. It reduced the errors in the Julian calendar by removing three days every four centuries; if the year ends in two noughts it is only a leap year if it is divisible by 400. So, for example, 2000 was a leap year, but 1700, 1800 and 1900 were not. 2100 will not be a leap year either.

## celestial sphere
An imaginary sphere, usually centred on the Earth, of arbitrarily large radius on the surface of which the stars can be considered to be fixed.

## circumpolar stars
Stars whose angular distances from the north or south celestial pole are sufficiently small that they never dip below the horizon.

## comet
A diffuse member of the Solar System, usually with a highly elongated orbit, which becomes visible near the Sun. It has a bright head and one or more diffuse tails of variable length.

## companion star
The fainter of the pair of stars in a visual-**binary star** system.

## conjunction
The moment when two celestial bodies occupy the same position in the sky or share a common
coordinate when viewed from a particular place. Thus **heliocentric conjunction**, and **conjunction in
right ascension**.

## coordinate systems
Frames of reference by means of which the position of any point can be uniquely specified. In astronomy, the systems take their names from the fundamental planes on which they are based. Thus the **ecliptic coordinate system** measures longitude round from the first point of Aries, in the plane of the ecliptic and latitude northwards from it. The **equatorial coordinate system** measures right ascension round from Aries in the plane of the Earth’s equator, and declination northwards from it. In the **horizon coordinate system**, the azimuth is measured round from the north point in the sense NESW and the altitude is the angle up from the horizon. The **galactic coordinate system** specifies position by longitude measured in the galactic plane round from the direction of the galactic centre and by latitude
measured perpendicular to the plane. **Heliographic coordinates** enable the position of an object on the surface of the Sun to be specified with respect to the solar equator and a fundamental meridian assumed to rotate at a uniform rate. **Selenographic coordinates** define positions on the surface of the Moon with
respect to the lunar equator and the mean **sub-Earth point**.

## coordinated universal time (UTC)
The time scale available from broadcast time signals. It differs from **International atomic time (TAI)** by a whole number of seconds, and is maintained within 0.9 s of
universal time (strictly UT1) by the insertion of leap seconds, usually at the ends of June or December.

## culmination
The moment at which a celestial body crosses the observer’s meridian. Circumpolar stars
cross the meridian above the horizon twice in one day, giving **upper culmination** and **lower culmination**.

## day
The interval between two successive transits across the observer’s meridian of a fixed star (**sidereal day**), of the Sun (**solar day**), or of a fictitious body called the mean Sun which moves at a uniform rate along the equator (**mean solar day**).

## daylight saving time
see **time**.

## declination
In the equatorial coordinate system, the angle measured perpendicular to the equator (north positive, south negative).

## dynamical time
The family of time scales introduced in 1984 that replaces **ephemeris time**. See **time**.

## earthshine
Light reflected from the Earth which sometimes illuminates the dark portion of the Moon’s
disc, making it visible.

## eccentricity
A measure of the degree of elongation of an ellipse, equal to the ratio of the distance of the focus from the centre to the length of the **semi-major axis**.

## eclipse
The passage of the Moon through the Earth’s shadow (**lunar eclipse**) or parts of the Earth through the Moon’s shadow (**solar eclipse**). If, at the moment of greatest eclipse, the Moon or Sun is only partly obscured it is a **partial eclipse**; if completely obscured it is a **total eclipse**. If during a solar eclipse the
Moon obscures the central part of the Sun’s disc but leaves an unobscured ring around its edge, then it is an **annular eclipse**.

## ecliptic
The plane containing the orbit of the Earth about the Sun.

## ellipse
A type of regular closed curve, oval in shape, of which a circle is a special case. It is traced by a point moving in such a manner that it keeps constant the sum of its distances from two fixed points, each of which is called a **focus** of the ellipse. The longest diameter of the ellipse, which goes through both foci and the centre, is called the **major axis**, the portion from the centre to the curve in either direction being called the **semi-major axis**.

## ephemeris time (ET)
See **time**.

## epoch
A particular moment specified as the reference point from which time is measured. The dates 1950.0 (strictly 1950 January 0.923) and 2000.0 (2000 January 1.5) are often used as standard epochs.

## equation of the centre
A relation between the true and mean anomalies which is an approximation to Kepler’s equation. In its simplest form it is

_v_ = _M_ + 2_e_ sin _M_,

where _v_ and _M_ are expressed in radians, useful for values of _e_ less than about 0.1.

## equation of the equinoxes
Apparent sidereal time minus mean sidereal time, taking account of the effect of **nutation** on the positions of the **equinoxes**.

## equation of time
The difference between the real solar time and the mean solar time.

## equator
The plane through the centre of the Earth which is perpendicular to the spin axis.

## equinox
The moment at which the Sun crosses the celestial equator. This occurs on about 21 March when its right ascension is zero (the **vernal equinox**) and about 22 September when its right ascension is 12 h (the **autumnal equinox**). The positions of the equinoxes on the celestial sphere lie along the line of the intersection of the planes of the equator and the ecliptic.

## evection
A correction to the Moon’s orbital motion taking account of slight variations in the apparent value
of the eccentricity of its orbit.

## extinction
The attenuation and colouring of light as it travels through a medium; in particular, **atmospheric extinction**.

## figure of the Earth
The true shape of the Earth. It is often approximated by a **spheroid of revolution**, a geometrical shape in which any cross-section parallel to the equator is a circle, while any cross-section through the north–south axis is an ellipse with the minor axis coincident with the diameter joining the north and south poles.

## first point of Aries
The position on the celestial sphere of the **vernal equinox**.

## focus of an ellipse
see **ellipse**.

## geocentric coordinates
Coordinates measured with respect to the centre of the Earth. Hence the **geocentric latitude** is the angle between the equator and a point on the surface of the Earth, as measured at the centre of the Earth.

## geocentric parallax
The angle subtended at a heavenly body by the centre of the Earth and the point of observation on the Earth’s surface.

## geostationary satellite
A body orbiting the Earth in the plane of the equator in such a direction and at such a height that its orbital period equals 1 day so that it keeps constant position with respect to the Earth’s surface.

## GPS time
An atomic time kept by the US Naval Observatory and broadcast by the satellites of the global positioning system. GPS time was equal to UTC on 1980 January 6 0.0, but, unlike UTC, is not adjusted by the insertion of leap seconds. Hence GPS time is equal, in June 2011, to UTC + 15 seconds (kept to within a microsecond) and is the time you can extract from your GPS navigation device.

## gravity
The mutual force of attraction between any two bodies which is proportional to the product of their masses and inversely proportional to the square of their separation.

## great circle
Any circle drawn on the surface of a sphere whose centre is the same as that of the sphere.

## Greenwich mean time (GMT)
This is ambiguous and is not now used in the _Astronomical Almanac_. Its meaning in civil life is usually the same as UTC, though previously it has been used to mean UT. Before 1925 it was reckoned from Greenwich mean noon (12 h UT).

## Greenwich meridian
That half of the great circle on the surface of the Earth passing through the north and south poles and through the reference point in Greenwich, England. It is taken as the line of longitude 0◦.

## horizontal parallax
The geocentric parallax when the celestial body is on the observer’s horizon; hence **equatorial horizontal parallax** when the observer is also on the equator.

## hour angle
The difference between the local sidereal time and the right ascension.

## inclination of orbit
The angle between the plane of the orbit and the plane of the ecliptic.

## inner planet
A planet whose semi-major axis is smaller than that of the Earth; that is the planets Mercury and Venus.

## international atomic time (TAI)
see **time**.

## Julian date
The number of Julian days that have elapsed since the fundamental epoch Greenwich mean noon of 1 January 4713 BC. For 2010 January 0.0 its value is 2 455 196.5. The **Julian day number** is the integer part of the Julian date. See also **modified Julian date** (MJD).

## Kepler’s equation
The relation between the mean and eccentric anomalies, _M_ and _E_,

_E_ − _e_sin_E_ = _M_,

where the angles are expressed in radians.

## latitude
The coordinate expressing the angle (north positive, south negative) perpendicular to a fundamental plane, hence **ecliptic latitude** and **galactic latitude**. On the Earth, the **geographical latitude** is measured with respect to the equator. The ecliptic latitude can be measured either at the Earth (**geocentric**) or at the Sun (**heliocentric**).

## librations
Variations in the orientation of the Moon’s surface with respect to an observer on the Earth.

## light time
The time it takes light signals from a celestial body to reach an observer.

## longitude
The coordinate expressing the angle round from a fixed direction measured in a fundamental plane, hence **ecliptic longitude** and **galactic longitude**. On the Earth, the **geographical longitude** is measured at the equator. The ecliptic longitude can be measured either at the Earth (**geocentric**) or at the Sun (**heliocentric**).

## lunation
The period between two successive new Moons.

## luni–solar precession
The slow retrograde motion of the first point of Aries along the equator caused by the combined effects of the Sun and the Moon on the slightly non-spherical Earth.

## magnitude

(i) the unit defined on a logarithmic scale which measures the brightness of a celestial object considered as a point.

(ii) **in a lunar eclipse**, the fraction of the lunar diameter obscured by the shadow of the Earth at the moment of greatest eclipse, measured along the common diameter.

(iii) **in a solar eclipse**, the fraction of the solar diameter obscured by the Moon at the moment of greatest eclipse, measured along the common diameter.

## mean Sun
A fictitious heavenly body that moves at a uniform rate along the equator making one complete circuit in the same time (1 year) as the real Sun takes to make a complete circuit.

## meridian
That half of a great circle which is terminated at the north and south poles. On the Earth a meridian is a line of longitude. On the celestial sphere, the meridian which passes through the zenith is called the **observer’s meridian**.

## modified Julian date (MJD)
The number of Julian days elapsed since 1858 November 17.0.

## month
The period taken by the Moon to make one complete circuit of its orbit from reference point to reference point. The **draconic month** or **nodal month** takes the ascending node as the reference and is equal to 27.212 2 mean solar days. The **sidereal month** is reckoned against the background of stars and is equal to 27.321 7 mean solar days. The Sun is used as the reference for the **synodic month** of 29.530 6 mean solar days, and the perigee for the **anomalistic month** of 27.554 6 mean solar days.

## nadir
The point on the celestial sphere diametrically opposite the **zenith**.

## node
A point on the celestial sphere where the great circle representing the orbit cuts the great circle representing the plane of the ecliptic. The point where the orbiting body is moving from below (south of) to above the ecliptic is called the **ascending node**; the other is the **descending node**.

## noon
The instant at which the Sun crosses the observer’s meridian.

## north celestial pole
The point at which the projection of the Earth’s rotation axis through the north pole intersects the celestial sphere.

## nutation
A small periodic wobbling motion of the Earth’s rotation axis.

## obliquity of the ecliptic
The angle at which the plane of the ecliptic is inclined to the plane of the equator.

## opposition
The moment when two celestial bodies occupy opposite positions in the sky, or have longitudes different by 180◦ , when viewed at a particular place.

## orbit
The path through space taken by a body gravitationally attracted to another body.

## orbital elements
The quantities which need to be known in order to specify an orbit uniquely.

## osculating elements
The elements describing the elliptical orbit followed by a body if all perturbing influences vanish. Since perturbations disturb the true orbit of any member of the Solar System, the osculating elements are constantly changing.

## outer planet
Those planets having semi-major axes larger than that of the Earth. The major outer planets are Mars, Jupiter, Saturn, Uranus and Neptune. In 2006, Pluto was reclassified as a dwarf planet by the International Astronomical Union.

## parabolic orbit
An orbit in which the velocity at any point is equal to the escape velocity.

## parallax
The amount by which the apparent position of a celestial object shifts as the point of observation is changed.

## penumbra
The outer portion of a shadow where the light is only partially cut off.

## periastron
The point in an orbit about a star that is nearest to the star.

## perigee
The point in an orbit about the Earth which is nearest the Earth.

## perihelion
The point of closest approach to the Sun in an orbit about the Sun.

## period of orbit
The time taken by the orbiting body to make one complete circuit.

## perturbations
Deviations from true elliptical motion caused by the gravitational fields of other members of the Solar System.

## phase
(i) **of Moon or planet**: the fraction of the area of the disc which is illuminated. When the dark side of the Moon faces the Earth, the phase is zero and it is **new Moon**. At the **first quarter** and the **third quarter**, the phase is equal to a half and the Moon is in **quadrature**. **Full Moon** has a phase equal to one. Whenever the phase is greater than a half, the Moon is described as **gibbous**.

(ii) **of an eclipse**: the stage of a lunar or solar eclipse during which the eclipsed body is partly obscured (**partial phase**) or totally obscured (**total phase**). During a lunar eclipse, the Moon is in the penumbra of the Earth’s shadow during the **penumbral phase** and partially or totally in the umbra during the **umbral phase**. The partial and total phases occur during the umbral phase.

## planet
A solid body in closed orbit about a star. In our own Solar System, the major planets are (in order of increasing distance from the Sun) Mercury, Venus, Earth, Mars, Jupiter, Saturn, Uranus, and Neptune. Pluto, formerly recognised as a planet, was reclassified as a dwarf planet in 2006.

## polar distance
The angle on the celestial sphere from the celestial pole.

## pole
The point on a sphere which is perpendicular to a given plane. Hence **pole of the ecliptic** and **pole of the equator** (each has two poles called north and south poles for short).

## position-angle
A celestial angle measured from 0◦ to 360◦ eastwards from the north.

## precession
see **luni-solar precession**.

## primary star
The brighter of the pair of stars in a visual-binary system.

## prograde motion
Motion in the same sense as that of all the planets about the Sun. When looking down on the Solar System from the north celestial pole, prograde motion is counter-clockwise.

## radian
A natural unit used to measure angles, equal to 1/2π revolutions and 180/π degrees.

## radius vector
The line joining the principal focus to the position of the orbiting body on its orbital ellipse.

## reflectivity of planet
A measure of a planet’s ability to reflect sunlight; a factor affecting its apparent brightness.

## refraction
see **atmospheric refraction**.

## retrograde motion
Motion in the opposite sense to that of all the planets about the Sun. When looking down on the Solar System from the north celestial pole, retrograde motion is clockwise.

## right ascension
In the equatorial coordinate system the angle measured round from the first point of Aries in the plane of the equator, in the sense NWSE.

## rising
The moment when a celestial body crosses the horizon on the way up.

## Saros cycle
The period of 18 years 11 days and 8 hours after which the pattern of lunar and solar eclipses tends to repeat.

## second (SI second)
The unit of time for the **international atomic time (TAI)** scale defined to be exactly 9 192 631 770 cycles of radiation corresponding to the transition between two hyperfine levels in the ground state of caesium 133.

## semi-major axis
see **ellipse**.

## setting
The moment when a celestial body crosses the horizon on the way down.

## solar elongation
The angle between the lines of sight to the Sun and to the celestial body in question.

## Solar System
The Sun and all the bodies, planets, comets and asteroids in closed orbits about it.

## solstice
The points at which the apparent longitude of the Sun is 90◦ and 270◦, or the moments at which the Sun is at either of these points. These occur around 21 June and 21 December.

## sub-Earth point
The point on a celestial body (especially the Moon) where the line joining the centre of the Earth and the centre of the body intersects the surface of the body.

## synodic period
The time between successive conjunctions in longitude.

## terminator
The line marking the boundary between the dark and sunlit hemispheres of a member of the Solar System.

## terrestrial dynamical time (TDT)
see **time**.

## terrestrial time (TT)
see **time**.

## time
### atomic time
Time measured with respect to the natural period of oscillations of an atomic system. Caesium beam clocks currently constitute the most precise time-keepers available, and the SI unit of atomic time is defined in terms of the caesium 133 atom (see **second**). **International atomic time (TAI)** is the continuous scale resulting from analyses by the Bureau International des Poids et Mesures of atomic time standards in many countries, starting from the epoch 1958 January 1. **Coordinated universal time** (UTC) is the time scale distributed by standard time services and is tied to both TAI and UT in such a manner that (a) it differs from TAI by a whole number of
seconds, and (b) it is never more than 0.9 s different from UT (strictly UT1). This is achieved by the introduction of leap seconds into UTC from time to time. UTC constitutes the basis for legal time keeping in most parts of the world. **Terrestrial time (TT)** (**called terrestrial dynamic time (TDT)** until 1991) is used as the argument in theories of celestial dynamics and in the compilation of the _Astronomical Almanac_. It is equal to TAI +32.184 s. **TDT** had replaced **ephemeris time (ET)** in 1984, which was itself derived from analyses of the Moon’s motion.

### solar time
Time measured with respect to the motion of the Sun or a fictitious body, no longer used, called the mean Sun (**mean solar time**). **Universal time (UT)** is, broadly speaking, the mean solar time as measured on the Greenwich meridian. It is formally defined by a mathematical formula as a function of **sidereal time** (see below), and is thus determined from observations of the stars. A direct application of the formula gives UT0; with a small correction for polar motion the scale UT1 is obtained. Whenever the term UT is used, UT1 is usually implied. **British summer time (BST)** is 1 hour ahead of UT and is an example of **daylight saving time** in which the time is adjusted to make the working day fit more conveniently into the daylight hours.

### sidereal time
Time measured with respect to the apparent motion of the stars. The **local sidereal time** at any place is equal to the hour angle of the first point of Aries; local sidereal time on the Greenwich meridian is called **Greenwich sidereal time**. The difference between **apparent sidereal time** and **mean sidereal time** is called the **equation of the equinoxes**, and takes account of **nutation**. It may be as much as 1.2 seconds.

## time zone
A longitudinal strip on the surface of the Earth in which the **zone time**, usually a whole number of hours before or after UT, is adopted as the local civil time by national or international agreement.

## transit
The moment at which a celestial body crosses the observer’s meridian.

## twilight
That period of semi-darkness after sunset or before sunrise during which the sun’s zenith distance is more than 90◦ but less than some agreed figure. This figure is 108◦ for **astronomical twilight** and 102◦ for **nautical twilight**, while for **civil twilight** it is 96◦.

## umbra
The inner portion of a shadow where the light is completely obscured.

## universal time
see **time**.

## variation
A correction to the Moon’s orbital motion about the Earth that takes account of the changing solar gravitational field.

## vernal equinox
see **equinox**.

## year
The interval between two successive passages of the Sun through a reference point. A particular point among the stars is used as reference in the **sidereal year**, equal to 365.2564 mean solar days. The **tropical year**, 365.242 191 mean solar days, uses the first point of Aries as its reference. When no qualifying adjective is used with the word 'year', it is usually the tropical year that is meant. Perturbations to the Earth’s orbit by the other planets cause small changes in the Earth’s orbital elements. The **anomalistic year**, 365.2596 mean solar days, is the interval between two successive passages of the Sun through perigee. The **Besselian year**, not used since 1984, is the period of one complete revolution in right ascension of the fictitious mean Sun as defined by the astronomer Simon Newcomb (1835–1909). It is almost the same as the tropical year, but begins when the right ascension of the Sun is exactly 240◦ ; this instant falls very near the beginning of the **civil year**.

## zenith
The point directly overhead at the observer. The **zenith angle** or **zenith distance** of a star is the angle between the star and the zenith.

## zone correction
The number of hours that needs to be added to or subtracted from UT to get the **zone time**.
